pub enum RequestEventKind {
AttemptStarted,
AttemptSucceeded,
AttemptFailed,
RetryScheduled,
RegionRedirected,
}Expand description
Stage of one request attempt.
Variants
AttemptStarted
A signed request attempt is about to be sent.
AttemptSucceeded
An attempt completed successfully.
AttemptFailed
An attempt failed and will not be retried.
RetryScheduled
A retry was scheduled after an attempt failed.
RegionRedirected
AWS supplied a validated region correction and the request will be re-signed.