pub enum RetryClassification {
Never,
Retryable,
Throttled,
}Expand description
Whether an operation may be retried after an error.
Variants
Never
Retrying is not expected to succeed.
Retryable
The failure is transient, subject to operation replayability.
Throttled
The service throttled the request, subject to operation replayability.