pub struct Conditions {
pub if_match: Option<String>,
pub if_none_match: Option<String>,
pub if_modified_since: Option<OffsetDateTime>,
pub if_unmodified_since: Option<OffsetDateTime>,
}Expand description
Conditional headers shared by object operations.
Fields
if_match: Option<String>Match this entity tag before performing the operation.
if_none_match: Option<String>Perform the operation only when this entity tag does not match.
if_modified_since: Option<OffsetDateTime>Perform the operation only if the object changed after this instant.
if_unmodified_since: Option<OffsetDateTime>Perform the operation only if the object did not change after this instant.