pub struct Credentials { /* private fields */ }Expand description
AWS-compatible credentials and optional expiration.
Secret values are zeroized on drop. Its Debug implementation redacts all
credential material, including the access-key identifier.
Implementations
Sourceimpl Credentials
impl Credentials
Sourcepub fn new(
access_key_id: impl Into<String>,
secret_access_key: impl Into<String>,
session_token: Option<String>,
) -> Result<Self, S3Error>
pub fn new( access_key_id: impl Into<String>, secret_access_key: impl Into<String>, session_token: Option<String>, ) -> Result<Self, S3Error>
Creates non-expiring credentials.
Sourcepub fn with_expiration(
access_key_id: impl Into<String>,
secret_access_key: impl Into<String>,
session_token: Option<String>,
expires_at: Option<OffsetDateTime>,
) -> Result<Self, S3Error>
pub fn with_expiration( access_key_id: impl Into<String>, secret_access_key: impl Into<String>, session_token: Option<String>, expires_at: Option<OffsetDateTime>, ) -> Result<Self, S3Error>
Creates credentials with an optional expiration time.
Sourcepub fn access_key_id(&self) -> &str
pub fn access_key_id(&self) -> &str
Returns the access-key identifier for signing.
Sourcepub fn secret_access_key(&self) -> &SecretString
pub fn secret_access_key(&self) -> &SecretString
Returns the secret access key for signing.
Sourcepub fn session_token(&self) -> Option<&SecretString>
pub fn session_token(&self) -> Option<&SecretString>
Returns the optional session token for signing.
Sourcepub fn expires_at(&self) -> Option<OffsetDateTime>
pub fn expires_at(&self) -> Option<OffsetDateTime>
Returns the credential expiration time, when supplied by the provider.
Sourcepub fn expires_by(&self, time: OffsetDateTime) -> bool
pub fn expires_by(&self, time: OffsetDateTime) -> bool
Returns whether the credentials expire at or before time.