pub struct MultipartUpload { /* private fields */ }Expand description
Explicit state needed to resume or clean up an in-progress multipart upload.
Implementations
Sourceimpl MultipartUpload
impl MultipartUpload
Sourcepub fn new(key: ObjectKey, upload_id: UploadId) -> Self
pub fn new(key: ObjectKey, upload_id: UploadId) -> Self
Starts tracking a newly created upload.
Sourcepub fn record_part(&mut self, part: CompletedPart) -> Result<(), MultipartError>
pub fn record_part(&mut self, part: CompletedPart) -> Result<(), MultipartError>
Records a completed part while retaining canonical ascending order.
Sourcepub fn completed_parts(&self) -> &[CompletedPart]
pub fn completed_parts(&self) -> &[CompletedPart]
Returns completed parts in validated ascending order.