pub struct S3ConfigBuilder { /* private fields */ }Expand description
Builder for S3Config.
Implementations
Sourceimpl S3ConfigBuilder
impl S3ConfigBuilder
Sourcepub fn endpoint(self, endpoint: Endpoint) -> Self
pub fn endpoint(self, endpoint: Endpoint) -> Self
Sets a custom endpoint. HTTP endpoints still require explicit opt-in.
Sourcepub fn addressing_style(self, style: AddressingStyle) -> Self
pub fn addressing_style(self, style: AddressingStyle) -> Self
Sets the bucket addressing style.
Sourcepub fn allow_http_for_local_testing(self) -> Self
pub fn allow_http_for_local_testing(self) -> Self
Explicitly permits plain HTTP for local S3-compatible testing.
This does not disable TLS verification for HTTPS endpoints and should not be enabled for endpoints reached over an untrusted network.
Sourcepub fn connect_timeout(self, timeout: Duration) -> Self
pub fn connect_timeout(self, timeout: Duration) -> Self
Sets the connection-establishment timeout.
Sourcepub fn attempt_timeout(self, timeout: Duration) -> Self
pub fn attempt_timeout(self, timeout: Duration) -> Self
Sets the timeout for each individual request attempt.
Sourcepub fn operation_timeout(self, timeout: Duration) -> Self
pub fn operation_timeout(self, timeout: Duration) -> Self
Sets the overall timeout for one primitive S3 operation across retries.
Managed multipart uploads instead use the transfer and cleanup deadlines
in crate::MultipartOptions.
Sourcepub fn idle_body_timeout(self, timeout: Duration) -> Self
pub fn idle_body_timeout(self, timeout: Duration) -> Self
Sets the maximum idle period while streaming a response body.
Sourcepub fn max_xml_response_size(self, bytes: usize) -> Self
pub fn max_xml_response_size(self, bytes: usize) -> Self
Sets the maximum XML response body size.
Sourcepub fn max_error_response_size(self, bytes: usize) -> Self
pub fn max_error_response_size(self, bytes: usize) -> Self
Sets the maximum error response body size.
Sourcepub fn retry_policy(self, policy: RetryPolicy) -> Self
pub fn retry_policy(self, policy: RetryPolicy) -> Self
Sets the retry policy.
Sourcepub fn user_agent(self, user_agent: impl Into<String>) -> Self
pub fn user_agent(self, user_agent: impl Into<String>) -> Self
Sets the HTTP user-agent value.
Sourcepub fn credentials_provider(
self,
provider: Arc<dyn CredentialsProvider>,
) -> Self
pub fn credentials_provider( self, provider: Arc<dyn CredentialsProvider>, ) -> Self
Sets the asynchronous credential provider.
Sourcepub fn observer(self, observer: Arc<dyn RequestObserver>) -> Self
pub fn observer(self, observer: Arc<dyn RequestObserver>) -> Self
Installs a dependency-free observer for sanitized request lifecycle events.