pub trait RequestObserver: Send + Sync {
// Required method
fn on_event(&self, event: RequestEvent<'_>);
}Expand description
Receives sanitized request lifecycle events.
Implementations must return quickly and must not block the async executor. Panics are isolated by the client and cannot fail an S3 operation.
Required Methods
Sourcefn on_event(&self, event: RequestEvent<'_>)
fn on_event(&self, event: RequestEvent<'_>)
Records one request lifecycle event.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".