Crate s3_wire

Crate s3_wire 

s3-wire

This name has been established for the upcoming s3-wire S3-compatible client. The initial implementation is under development at https://github.com/runtrue/s3-rs.

Version 0.0.0 contains no client implementation and must not be used.

Constants

IMPLEMENTATION_AVAILABLE
Indicates that version 0.0.0 is a non-functional name-establishment release.