pub struct Endpoint { /* private fields */ }Expand description
A validated S3 service endpoint.
Implementations
Sourceimpl Endpoint
impl Endpoint
Sourcepub fn new(endpoint: impl AsRef<str>) -> Result<Self, S3Error>
pub fn new(endpoint: impl AsRef<str>) -> Result<Self, S3Error>
Parses and validates an HTTP or HTTPS endpoint.
Errors
Returns an error when the URL is not an absolute HTTP(S) URL, contains credentials, a query, or a fragment, or has no usable host.
Sourcepub fn for_aws_region(region: &str) -> Result<Self, S3Error>
pub fn for_aws_region(region: &str) -> Result<Self, S3Error>
Creates the standard regional AWS S3 endpoint.
Errors
Returns an error when region cannot be represented safely in an AWS
regional hostname.
Sourcepub fn for_aws_region_variant(
region: &str,
variant: AwsEndpointVariant,
) -> Result<Self, S3Error>
pub fn for_aws_region_variant( region: &str, variant: AwsEndpointVariant, ) -> Result<Self, S3Error>
Creates a partition-aware regional AWS S3 endpoint variant.
China regions use the amazonaws.com.cn DNS suffix. Commercial and
GovCloud regions use amazonaws.com. The region is still used as the
SigV4 signing region by crate::S3Config.
Errors
Returns an error when region cannot be represented safely in an AWS
regional hostname.