pub struct S3Config { /* private fields */ }Expand description
Validated configuration used to construct an S3 client.
Implementations
Sourceimpl S3Config
impl S3Config
Sourcepub fn builder() -> S3ConfigBuilder
pub fn builder() -> S3ConfigBuilder
Starts a configuration builder with HTTPS-safe defaults.
Sourcepub fn addressing_style(&self) -> AddressingStyle
pub fn addressing_style(&self) -> AddressingStyle
Returns the configured bucket addressing style.
Sourcepub fn connect_timeout(&self) -> Duration
pub fn connect_timeout(&self) -> Duration
Returns the connection-establishment timeout.
Sourcepub fn attempt_timeout(&self) -> Duration
pub fn attempt_timeout(&self) -> Duration
Returns the timeout applied to a single request attempt.
Sourcepub fn operation_timeout(&self) -> Duration
pub fn operation_timeout(&self) -> Duration
Returns the overall operation timeout across all attempts.
Sourcepub fn idle_body_timeout(&self) -> Duration
pub fn idle_body_timeout(&self) -> Duration
Returns the maximum permitted gap between response body chunks.
Sourcepub fn max_xml_response_size(&self) -> usize
pub fn max_xml_response_size(&self) -> usize
Returns the maximum XML response body size in bytes.
Sourcepub fn max_error_response_size(&self) -> usize
pub fn max_error_response_size(&self) -> usize
Returns the maximum error response body size in bytes.
Sourcepub fn retry_policy(&self) -> &RetryPolicy
pub fn retry_policy(&self) -> &RetryPolicy
Returns the retry policy.
Sourcepub fn user_agent(&self) -> &str
pub fn user_agent(&self) -> &str
Returns the HTTP user-agent value.
Sourcepub fn credentials_provider(&self) -> &Arc<dyn CredentialsProvider>
pub fn credentials_provider(&self) -> &Arc<dyn CredentialsProvider>
Returns the credential provider.